#ifndef _FILEUTIL_H
#define _FILEUTIL_H

char *read_file(char *progname, char *fileName);
char *createOutputFileName( char *inputFileName, char *outputDir );

#endif //_FILEUTIL_H
